@@ -32,7 +32,7 @@ void clearTimeWindows(TimeWindow *node)
     {
         clearTimeWindows(node->next);
     }
-    free(node->r0);
+    free(node->beta);
     node->prev = NULL;
     free(node);
 }
@@ -43,8 +43,8 @@ void clearTimeWindows(TimeWindow *node)
  */
 TimeWindow *importTimeWindowData(int n_pop,
                                  int total,
-                                 double *all_r0,
-                                 double *dist_param,
+                                 double *all_beta,
+                                 double *dist_phi,
                                  double *m,
                                  double *imm_frac,
                                  double *hosp_rate,
@@ -62,14 +62,14 @@ TimeWindow *importTimeWindowData(int n_pop,
     if (window_length[0] > 1)
     {
         TimeWindow *temp_node = (TimeWindow *)malloc(sizeof(TimeWindow));
-        temp_node->r0 = (double *)malloc(n_pop * sizeof(double));
+        temp_node->beta = (double *)malloc(n_pop * sizeof(double));
 
-        // Populate r0 with this time window's value for each population
+        // Populate beta with this time window's value for each population
         for (int this_pop = 0; this_pop < n_pop; this_pop++) {
-            temp_node->r0[this_pop] = all_r0[this_pop * total + index];
+            temp_node->beta[this_pop] = all_beta[this_pop * total + index];
         }
 
-        temp_node->dist_param = dist_param[0];
+        temp_node->dist_phi = dist_phi[0];
         temp_node->m = m[0];
         temp_node->imm_frac = imm_frac[0];
         if (hosp_rate != NULL) temp_node->hosp_rate = hosp_rate[0];
@@ -86,14 +86,14 @@ TimeWindow *importTimeWindowData(int n_pop,
     while (index < total)
     {
         TimeWindow *temp_node = (TimeWindow *)malloc(sizeof(TimeWindow));
-        temp_node->r0 = (double *)malloc(n_pop * sizeof(double));
+        temp_node->beta = (double *)malloc(n_pop * sizeof(double));
 
-        // Populate r0 with this time window's value for each population
+        // Populate beta with this time window's value for each population
         for (int this_pop = 0; this_pop < n_pop; this_pop++) {
-            temp_node->r0[this_pop] = all_r0[this_pop * total + index];
+            temp_node->beta[this_pop] = all_beta[this_pop * total + index];
         }
 
-        temp_node->dist_param = dist_param[index];
+        temp_node->dist_phi = dist_phi[index];
         temp_node->m = m[index];
         temp_node->imm_frac = imm_frac[index];
         if (hosp_rate != NULL) temp_node->hosp_rate = hosp_rate[index];
